==============
click-skeleton
==============
+---------------+-----------------+
|     Tools     |      Result     |
+===============+=================+
|     Coverage  |   |coverage|    |
+---------------+-----------------+

.. |coverage| image:: https://github.com/AdrienPensart/click-skeleton/blob/master/doc/coverage.svg
   :alt: Coverage badge

Description
-----------
Library to build a CLI with a well defined skeleton and helpers, including :

- completion
- real --help eagerness
- help and version colors
- readme generation
- -V / --version / version subcommand
- -h / --help / help subcommand
- subgroup creation and registering made easier

EXAMPLE CLI
-----------

